pub async fn cleanup_bundle(container_id: &ContainerId) -> Result<()>Expand description
Clean up a container’s bundle
Convenience function to remove a bundle from the default location.
Errors
Returns an error if cleanup fails.
pub async fn cleanup_bundle(container_id: &ContainerId) -> Result<()>Clean up a container’s bundle
Convenience function to remove a bundle from the default location.
Returns an error if cleanup fails.