pub enum WaitResult {
Satisfied,
TimedOutContinue,
TimedOutWarn {
service: String,
condition: DependencyCondition,
},
TimedOutFail {
service: String,
condition: DependencyCondition,
timeout: Duration,
},
}Expand description
Result of waiting for a dependency
Variants
Satisfied
Condition was satisfied
TimedOutContinue
Timed out, but action allows continuing
TimedOutWarn
Timed out with warning, continuing
TimedOutFail
Timed out and should fail (caller should handle this as an error)
Implementations
Sourceimpl WaitResult
impl WaitResult
Sourcepub fn is_satisfied(&self) -> bool
pub fn is_satisfied(&self) -> bool
Returns true if the wait was successful (condition satisfied)
Sourcepub fn should_continue(&self) -> bool
pub fn should_continue(&self) -> bool
Returns true if the wait timed out but should continue
Sourcepub fn is_failure(&self) -> bool
pub fn is_failure(&self) -> bool
Returns true if the wait failed and should not continue