Module env

Module env 

Environment variable resolution for $E: and $S: prefix syntax

Per V1_SPEC.md Section 7, values prefixed with $E: are resolved from the runtime environment at container start time.

Additionally, values prefixed with $S: are resolved from the secrets provider at container start time.

Structs

ResolvedEnv
Result of resolving environment variables

Enums

EnvResolutionError
Errors that can occur during environment variable resolution

Functions

get_env_references
Get list of $E: referenced variable names
get_secret_references
Get list of $S: referenced secret names
has_env_references
Check if any environment variables use $E: references
has_secret_references
Check if any environment variables use $S: secret references
resolve_env_value
Resolve a single environment variable value
resolve_env_vars
Resolve environment variables from a ServiceSpec env HashMap
resolve_env_vars_with_warnings
Resolve environment variables and return in OCI format with warnings
resolve_env_with_secrets
Extended environment resolution with secrets support
resolve_value_with_secrets
Resolve a single environment variable value with secrets support