pub struct HealthMonitor { /* private fields */ }Expand description
Continuous health monitor
Implementations
Sourceimpl HealthMonitor
impl HealthMonitor
pub fn new( id: ContainerId, checker: HealthChecker, interval: Duration, retries: u32, ) -> Self
Sourcepub fn with_callback(self, callback: HealthCallback) -> Self
pub fn with_callback(self, callback: HealthCallback) -> Self
Set a callback to be invoked when health state changes (healthy <-> unhealthy).
Sourcepub fn with_start_grace(self, grace: Duration) -> Self
pub fn with_start_grace(self, grace: Duration) -> Self
Set a startup grace period. The monitor will sleep for this duration before performing the first health check, giving the container time to initialize.
Sourcepub fn with_check_timeout(self, timeout: Duration) -> Self
pub fn with_check_timeout(self, timeout: Duration) -> Self
Set the timeout applied to each individual health check. Defaults to 5 seconds.
Sourcepub fn start(self) -> JoinHandle<()>
pub fn start(self) -> JoinHandle<()>
Start monitoring (spawns background task)
Sourcepub async fn state(&self) -> HealthState
pub async fn state(&self) -> HealthState
Get current health state