pub struct InitOrchestrator { /* private fields */ }Expand description
Orchestrates init actions for a container
Implementations
Sourceimpl InitOrchestrator
impl InitOrchestrator
Sourcepub fn new(id: ContainerId, spec: InitSpec) -> Self
pub fn new(id: ContainerId, spec: InitSpec) -> Self
Create a new init orchestrator
Sourcepub fn with_error_policy(
id: ContainerId,
spec: InitSpec,
error_policy: ErrorsSpec,
) -> Self
pub fn with_error_policy( id: ContainerId, spec: InitSpec, error_policy: ErrorsSpec, ) -> Self
Create a new init orchestrator with error policy
Sourcepub fn with_max_retries(self, max_retries: u32) -> Self
pub fn with_max_retries(self, max_retries: u32) -> Self
Set the maximum retry attempts
Sourcepub fn with_backoff_config(self, config: BackoffConfig) -> Self
pub fn with_backoff_config(self, config: BackoffConfig) -> Self
Set the backoff configuration
Sourcepub async fn run(&self) -> Result<()>
pub async fn run(&self) -> Result<()>
Run all init steps with error policy enforcement
The behavior on init failure depends on the errors.on_init_failure policy:
Fail(default): Stop container creation, return error immediatelyRestart: Retry init steps (up tomax_retries) with immediate retryBackoff: Retry with exponential backoff (1s, 2s, 4s, 8s, max 60s)
Errors
Returns an error if init steps fail and the error policy is Fail or all retries are exhausted.