pub struct ServiceInstance {
pub service_name: String,
pub spec: ServiceSpec,
/* private fields */
}Expand description
Service instance manages a single service’s containers
Fields
service_name: Stringspec: ServiceSpecImplementations
Sourceimpl ServiceInstance
impl ServiceInstance
Sourcepub fn new(
service_name: String,
spec: ServiceSpec,
runtime: Arc<dyn Runtime + Send + Sync>,
overlay_manager: Option<Arc<RwLock<OverlayManager>>>,
) -> Self
pub fn new( service_name: String, spec: ServiceSpec, runtime: Arc<dyn Runtime + Send + Sync>, overlay_manager: Option<Arc<RwLock<OverlayManager>>>, ) -> Self
Create a new service instance
Sourcepub fn with_proxy(
service_name: String,
spec: ServiceSpec,
runtime: Arc<dyn Runtime + Send + Sync>,
overlay_manager: Option<Arc<RwLock<OverlayManager>>>,
proxy_manager: Arc<ProxyManager>,
) -> Self
pub fn with_proxy( service_name: String, spec: ServiceSpec, runtime: Arc<dyn Runtime + Send + Sync>, overlay_manager: Option<Arc<RwLock<OverlayManager>>>, proxy_manager: Arc<ProxyManager>, ) -> Self
Create a new service instance with proxy manager for health-aware load balancing
Sourcepub fn with_dns(self, dns_server: Arc<DnsServer>) -> Self
pub fn with_dns(self, dns_server: Arc<DnsServer>) -> Self
Builder method to add DNS server for service discovery
Sourcepub fn set_dns_server(&mut self, dns_server: Arc<DnsServer>)
pub fn set_dns_server(&mut self, dns_server: Arc<DnsServer>)
Set the DNS server for service discovery
Sourcepub fn set_proxy_manager(&mut self, proxy_manager: Arc<ProxyManager>)
pub fn set_proxy_manager(&mut self, proxy_manager: Arc<ProxyManager>)
Set the proxy manager for health-aware load balancing
Sourcepub fn set_health_states(
&mut self,
states: Arc<RwLock<HashMap<String, HealthState>>>,
)
pub fn set_health_states( &mut self, states: Arc<RwLock<HashMap<String, HealthState>>>, )
Set the shared health states map so health callbacks can bridge state back to ServiceManager
Sourcepub async fn last_pulled_digest(&self) -> Option<String>
pub async fn last_pulled_digest(&self) -> Option<String>
Get the last observed image digest (after the most recent successful
pull). Returns None when no pull has happened yet, when the runtime
does not expose digests, or when no matching ImageInfo was found.
Sourcepub async fn scale_to(&self, replicas: u32) -> Result<()>
pub async fn scale_to(&self, replicas: u32) -> Result<()>
Scale to the desired number of replicas
This method uses short-lived locks to avoid blocking concurrent operations. I/O operations (pull, create, start, stop, remove) are performed without holding the containers lock to allow other operations to proceed.
Errors
Returns an error if image pull, container creation, or container lifecycle operations fail.
Sourcepub async fn replica_count(&self) -> usize
pub async fn replica_count(&self) -> usize
Get current number of replicas
Sourcepub async fn container_ids(&self) -> Vec<ContainerId>
pub async fn container_ids(&self) -> Vec<ContainerId>
Get all container IDs
Sourcepub fn containers(&self) -> &RwLock<HashMap<ContainerId, Container>>
pub fn containers(&self) -> &RwLock<HashMap<ContainerId, Container>>
Get read access to the containers map
This allows callers to access container overlay IPs and other metadata without copying the entire map.
Sourcepub fn has_overlay_manager(&self) -> bool
pub fn has_overlay_manager(&self) -> bool
Check if this service instance has an overlay manager configured
Sourcepub fn has_proxy_manager(&self) -> bool
pub fn has_proxy_manager(&self) -> bool
Check if this service instance has a proxy manager configured
Sourcepub fn has_dns_server(&self) -> bool
pub fn has_dns_server(&self) -> bool
Check if this service instance has a DNS server configured